@@ -7,7 +7,8 @@ import yaml
 from InquirerPy import inquirer, prompt
 from InquirerPy.base import Choice
 from InquirerPy.separator import Separator
-from InquirerPy.validator import PathValidator, NumberValidator
+from InquirerPy.utils import color_print
+from InquirerPy.validator import PathValidator
 
 yml_path = Path('config.yml')
 
@@ -30,15 +31,22 @@ def find_chromedriver(tl):
     paths = [Path.home() / "Downloads", Path.home() / "Desktop", Path("/")]
     start = time.time()
     for path in paths:
-        print(f"Searching for {chromedriver} in {path}")
+        color_print([("#DCE775", f"Searching for {chromedriver} in {path}")])
         f = find(chromedriver, path, tl - (time.time() - start))
         if f:
-            print("Found!")
+            color_print([("#00E676", "Found!")])
             return f
-    print("Not Found!")
+    color_print([("#B00020", "Not Found!")])
     return ''
 
 
+def find_id(url_or_id):
+    match = re.search(r"(id=)?(\d+)", url_or_id)
+    if match:
+        return int(match.group(2))
+    return None
+
+
 credentials_questions = [
     {
         "type": "list",
@@ -85,9 +93,11 @@ course_questions = [
     {
         "type": "input",
         "name": "id",
-        "message": "Enter Course ID in LMS:",
-        "validate": NumberValidator(),
-        "long_instruction": "For example for a course like `http://lms.com/course/view.php?id=1194`, id is `1194`",
+        "message": "Enter Course ID or just Course URL in LMS:",
+        "validate": lambda x: find_id(x) is not None,
+        "filter": lambda x: find_id(x),
+        "transformer": lambda x: find_id(x),
+        "long_instruction": "URL Something like `lms.com/course/view.php?id=1194` or just ID like `1194`",
     }
 ]
 
@@ -121,8 +131,8 @@ paths_questions = [
         "message": "Enter chromedriver path:",
         "name": "chromedriver",
         "validate": PathValidator(is_file=True, message="Input is not a file"),
-        "long_instruction": "If you don't know what is this, checkout https://github.com/itsamirhn/AutoLMS#how-to-download-chromedriver",
-        "only_files": True,
+        "long_instruction": "If you don't know what is this, checkout:\n"
+                            "https://github.com/itsamirhn/AutoLMS#how-to-download-chromedriver",
         "filter": lambda file: str(Path(file).absolute()),
         "default": lambda _: find_chromedriver(10)
     },
@@ -155,13 +165,14 @@ def prompt_config():
     finished = False
     while not finished:
         config["courses"].append(prompt_course())
-        finished = inquirer.confirm("Are you finished?", default=True).execute()
+        finished = inquirer.confirm("Are you finished adding Courses?", default=True).execute()
     return config
 
 
 def save_config(config):
     if not config:
         return
+    color_print([("#00E676", "New Config saved successfully!")])
     with open(yml_path, 'w+') as f:
         yaml.safe_dump(config, f)
 
